import { ref, reactive, computed, toRefs } from "vue";
import { Table } from "@/hooks/interface";
import { ColumnProps } from "@/components/LjVxeTable/interface";
import { ALLOW_EDIT_STATE } from "@/config/index";

interface defaultState {
  /**
   * @description 单据当前状态
   */
  orderStatus: string;
}
/**
 * @description 表格多选数据操作
 * @param {String} rowKey 当表格可以多选时，所指定的 id
 * */
export const useHooks = (t?: any) => {
  const state = reactive<defaultState>({
    orderStatus: ""
  });

  // 表格配置项
  const columns: ColumnProps<any>[] = [
    { type: "seq", title: "#", fixed: "left", width: 80 },
    {
      field: "deptname",
      title: "部门名称",
      basicinfo: {
        el: "input",
        editable: ALLOW_EDIT_STATE,
        rules: [{ required: true }]
      }
    },
    {
      field: "pricelistid",
      title: "价格表",
      basicinfo: {
        el: "select",
        span: 6,
        editable: ALLOW_EDIT_STATE,
        rules: [{ required: true }]
      }
    },
    {
      field: "springtypename",
      title: "弹簧分类",
      basicinfo: {
        el: "select",
        span: 6,
        editable: ALLOW_EDIT_STATE,
        rules: [{ required: true, message: "请选择价格表", trigger: "change" }]
      }
    },
    {
      field: "profitrate",
      title: "利润率",
      basicinfo: {
        el: "input",
        editable: ALLOW_EDIT_STATE,
        props: {
          placeholder: "请输入利润率"
        },
        rules: [{ required: true, pattern: new RegExp(/^[1-9]\d*(\.\d+)?$/), message: "利润率不能为0", trigger: "change" }]
      }
    },
    {
      field: "moneyrate",
      title: "汇率",
      basicinfo: {
        el: "input",
        editable: ALLOW_EDIT_STATE,
        props: {
          placeholder: "请输入汇率"
        },
        rules: [{ required: true, pattern: new RegExp(/^[1-9]\d*(\.\d+)?$/), message: "汇率不能为0", trigger: "change" }]
      }
    },
    {
      field: "if_rate_auto",
      title: "是否自动读取汇率",
      datatype: "checkbox",
      basicinfo: {
        el: "switch",
        editable: ALLOW_EDIT_STATE
      }
    },
    {
      field: "createtime",
      title: "建立时间",
      editHidden: true
    },
    {
      field: "modemp",
      title: "修改人",
      editHidden: true
    },
    {
      field: "moddate",
      title: "修改时间",
      editHidden: true
    },
    {
      field: "auditemp",
      title: "审核人",
      editHidden: true
    },
    {
      field: "audidate",
      title: "审核时间",
      editHidden: true
    },
    {
      field: "manage_amt",
      title: "部门管理费",
      basicinfo: {
        el: "input",
        editable: ALLOW_EDIT_STATE,
        props: {
          placeholder: "请输入部门管理费"
        },
        rules: [{ trigger: "change" }]
      }
    },
    {
      field: "mtrltype",
      title: "默认物料类别",
      basicinfo: {
        el: "tree-select",
        editable: ALLOW_EDIT_STATE
      }
    }
  ];

  return {
    ...toRefs(state),
    columns
  };
};
